@@ -20,4 +20,4 @@ if __name__ == "__main__":
             else:
                 query = pickle.loads(payload)
                 result = load_balancer.run_query(query)
-                connection.send(pickle.dumps(result))
+                connection.send(result)
