@@ -25,7 +25,7 @@ class Database():
         while self.has_queries.acquire():
             self.query_ended.clear()
             query = self.queries.get()
-            self.waiters[query.wait].executor = self.executors[query.type]
+            self.waiters[query.wait].executor = self.executors
             self.waiters[query.wait].run_query(query, self)
 
     def change_status(self, new_status):
