@@ -1,5 +1,6 @@
 import abc
 import inspect
+import pickle
 from datetime import datetime
 
 import django.db
@@ -25,6 +26,7 @@ class QueryExecutor(Executor):
         else:
             instance = query.model.models_manager.using(database.name)
             result = instance.__getattribute__(query.method)(*query.args, **query.kwargs)
+        result = pickle.dumps(result)
         database.load_balancer.end_query(query, result)
         now = datetime.now()
         current_time = now.strftime("%H:%M:%S")
